flagtypes

package
v0.0.0-...-7a31ef5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 4, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InputData

type InputData []string

InputData contains strings read from files or string value if file does not exist.

func (*InputData) Set

func (v *InputData) Set(str string) error

Set tries to read file with given string value. If such a file does not exist the value itself is used.

func (InputData) String

func (v InputData) String() string

type OutFile

type OutFile struct{ *os.File }

OutFile holds output file

func (*OutFile) Set

func (v *OutFile) Set(value string) (err error)

Set sets output file

func (OutFile) String

func (v OutFile) String() string

Jump to