package
Version:
v0.0.0-...-7a31ef5
Opens a new window with list of versions in this module.
Published: Dec 4, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
InputData contains strings read from files or string value if file does not exist.
Set tries to read file with given string value. If such a file
does not exist the value itself is used.
type OutFile struct{ *os.File }
OutFile holds output file
Source Files
¶
Click to show internal directories.
Click to hide internal directories.